public with sharing class TestRetrieveAllSignatures {
    
    public void testRetrieveAllSignatures(){
    	String packageId = 'k9WVYOK1fP_BA3TgG9N1LFXWejA=';
    	String documentId = '795c5a172e9a808979b872998639159c5386c56f065fe6df';
    	String signerId = 'esignguide2@mailinator.com';
    	
    	List<ESignLiveAPIObjects.Approval> allSignableSignatures = getAllSignableSignatures(packageId, documentId, signerId);
    	for(ESignLiveAPIObjects.Approval approval: allSignableSignatures){
    		System.debug('Approval ID: ' + approval.id + ', accepted at: ' + approval.accepted);
    		if(approval.fields != null && approval.fields.size() > 0){
	    		for(ESignLiveAPIObjects.Field field: approval.fields){
	    			System.debug('----Field ID:' + field.id + ', TYPE: ' + field.type + ' ' + field.subtype);
	    		}
    		}
    	}
    }
    
    
    
    public List<ESignLiveAPIObjects.Approval> getAllSignableSignatures(String packageId, String documentId, String signerId){
    	String resourceUrl = '/packages/'+packageId+'/documents/'+documentId+'/signers/'+signerId+'/approvals';
        HttpResponse response = doGet(resourceUrl);

        // Check response
        List<ESignLiveAPIObjects.Approval> signableSignatures = new List<ESignLiveAPIObjects.Approval>();
        if(response.getStatusCode() == 200)
        {
        	List<Object> signableSignaturesList = (List<Object>)JSON.deserializeUntyped(response.getBody());
            try
            {
            	for(Object signableSignatureObject: signableSignaturesList){
            		signableSignatures.add((ESignLiveAPIObjects.Approval)JSON.deserialize(JSON.serialize(signableSignatureObject), ESignLiveAPIObjects.Approval.class));
            	}
            }
            catch(Exception e)
            {
                throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error parsing Signable Signatures ' + e.getMessage());
            }
        }
        else
        {
            throw new ESignLiveRESTAPIHelper.ESignLiveRestAPIHelperException('Error get All Signable Signatures ' + response.getStatusCode() + ' - ' + response.getStatus() + ' - ' +  response.getBody());  
        }
        return signableSignatures;
    }
    
    
    
    private HttpResponse doGet(String resourceUrl){
        e_SignLive_Connection_Settings__c connectionSettings = e_SignLive_Connection_Settings__c.getInstance('Main');    
         // Build Request
        HttpRequest request = new HttpRequest();
        request.setEndpoint(connectionSettings.Endpoint__c + resourceUrl);
        request.setMethod('GET');
        request.setHeader('Authorization', 'Basic ' + connectionSettings.API_Key__c);
        request.setHeader('Content-type', 'application/json');

        // Send Request
        HttpResponse response = (new Http()).send(request);

        if(response != null && (response.getHeader('Content-Type')).contains('json'))
        {
            System.debug('=> Formating for JSON response');
            // Format responseBody string before returning
            String inboundResponseBody = ESignLiveJSONHelper.prepareInboundJSON(response.getBody());
            response.setBody(inboundResponseBody);
        }

        return response;
    }
    
    
}